@@ -5,12 +5,12 @@ pub use axi_dma::AxiDma;
 pub use axi_dma_async::AxiDmaAsync;
 pub use dma_buffer::DmaBuffer;
 
-#[cfg(any(target_arch = "armv7", target_arch = "aarch64"))]
+#[cfg(xilinx_dma_has_dmb)]
 mod dmb;
-#[cfg(any(target_arch = "armv7", target_arch = "aarch64"))]
+#[cfg(xilinx_dma_has_dmb)]
 pub use dmb::dmb;
 
-#[cfg(not(any(target_arch = "armv7", target_arch = "aarch64")))]
+#[cfg(not(xilinx_dma_has_dmb))]
 #[inline(always)]
 pub fn dmb() {
     // DMB is ARM-only, so we use a nop in other archs
